@@ -35,6 +35,7 @@
 #include <atk/atk.h>
 
 #include <droute/droute.h>
+#include <gmodule.h>
 
 #include "bridge.h"
 #include "event.h"
@@ -774,6 +775,14 @@ gtk_module_init (gint * argc, gchar ** argv[])
   return 0;
 }
 
+gchar*
+g_module_check_init (GModule *module)
+{
+  g_module_make_resident (module);
+
+  return NULL;
+}
+
 void
 gnome_accessibility_module_init (void)
 {
